<?php 
/**
 * @package Wapple_Architect
 * @author Rich Gubby
 * @version 1.5.5.1
 */
/*
Plugin Name: Wapple Architect
Plugin URI: http://mobilewebjunkie.com/wordpress-mobile-plugin-install-guide-and-faq/
Description: Wapple Architect Mobile Plugin for Wordpress is a plugin that allows you to mobilize your blog in minutes. After activating this plugin visit <a href="/wp-admin/admin.php?page=architect-basic">the settings page</a> and enter your Wapple Architect Dev Key.
Author: Rich Gubby
Version: 1.5.5.1
Author URI: http://mobilewebjunkie.com/
*/

// Added support for WP Super Cache
if(function_exists('add_cacheaction'))
{
	add_cacheaction('add_cacheaction', 'architectWPSuperCache');
	function architectWPSuperCache($string)
	{
		global $cache_rejected_uri;
		$cache_rejected_uri[] = $_SERVER["REQUEST_URI"];
	}
}
	
/** 
 * Define some defaults - shouldn't need to change these
 * Defaults are now inserted into the DB at installation - these are left in for legacy versions
 */
// Width of images on the homepage
define('ARCHITECT_HOME_IMAGESCALE', 50);
// Quality of images on the homepage
define('ARCHITECT_HOME_IMAGEQUALITY', 95);
// Width of images on post pages
define('ARCHITECT_SINGLE_IMAGESCALE', 50);
// Quality of images on post pages
define('ARCHITECT_SINGLE_IMAGEQUALITY', 95);
// Width of images on designated pages
define('ARCHITECT_PAGE_IMAGESCALE', 50);
// Quality of images on designated pages
define('ARCHITECT_PAGE_IMAGEQUALITY', 95);
// Length of chars in post before a new page
define('ARCHITECT_SINGLE_PAGINGLENGTH', 2000);

// Start output buffering
ob_start();

/**
 * Debug purposes only - you shouldn't need to change these
 */ 
// Force the mobile check to always return true
define('ARCHITECT_FORCE_MOBILE', false);
// Turn a bit more debug on than is normal
define('ARCHITECT_DEBUG', false);

require_once('admin'.DIRECTORY_SEPARATOR.'functions.php');

if(ARCHITECT_DEBUG)
{
	error_reporting(E_ALL);
	ini_set('display_errors', true);
}

if ( !defined('WP_CONTENT_DIR') )
	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down

if ( !defined('WP_PLUGIN_DIR') )
	define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash

if ( !defined('WP_CONTENT_URL') )
	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
	
if ( !defined('WP_PLUGIN_URL') )
	define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
	
if ( !defined('WP_UPLOAD_DIR') )
	define('WP_UPLOAD_DIR', WP_CONTENT_DIR . '/uploads' );

require_once('theme'.DIRECTORY_SEPARATOR.'functions.php');

if(!function_exists('simplexml_load_string') || (get_option('architect_devkey') == '' OR !get_option('architect_devkey')))
{
	function ArchitectInitError()
	{
		if(!isset($_REQUEST['page']) OR (isset($_REQUEST['page']) AND $_REQUEST['page'] != 'architect.php'))
		{
			echo '<div class="updated" style="background:#F24318;color:#000;border-color:#B23112;"><p>There was a problem initializing the Wapple Architect mobile plugin, please check <a href="/wp-admin/admin.php?page=architect-status">the Wapple Architect settings page</a> for more information</p></div>';
		}
	}
}

/**
 * Main device detection kick off function
 * - Sets up a few global variables that we're going to use later and initiates a check for mobile.
 * - If the check for mobile comes back true, amend the path to the theme
 * @param array $options
 * @access public
 * @return void
 */
function deviceDetection($options = array())
{
	// Only do this if we're on a non-admin page (for now!)
	if(!is_admin())
	{
		// Setup a global SOAP client so we can use the same one in the theme
		global $waplSoapClient;
		// Setup global headers so we don't have to get them twice
		global $waplHeaders;
		
		// Which communication method do we want to use?
		if(function_exists('curl_init'))
		{
			// Communicating via REST
			define('ARCHITECT_DO_SOAP', false);
			define('ARCHITECT_DO_REST', true);
		} else if(class_exists('SoapClient'))
		{
			// Check if the SOAP client is up
			if(!@file_get_contents('http://webservices.wapple.net/info.txt'))
			{
				define('ARCHITECT_DO_SOAP', false);
				define('ARCHITECT_DO_REST', false);
				return false;
			} else
			{
				// Communicating via SOAP
				define('ARCHITECT_DO_SOAP', true);
				define('ARCHITECT_DO_REST', false);
			}
		} else
		{
			return false;
		}
		if(!function_exists('simplexml_load_string'))
		{
			return false;
		}
		
		// Create the SOAP client
		if(ARCHITECT_DO_SOAP)
		{
			$waplSoapClient = __getSoapClient();
		} else
		{
			$waplSoapClient = null;
		}
		// Get device / browser header information 
		$waplHeaders = __getHeaders();

		// If __testForMobile() comes back true, amend template path
		if(__testForMobile())
		{
			if(get_option('architect_redirect'))
			{
				$url = get_option('architect_redirect_url');
				if($url && (strpos($url, 'http://') === 0))
				{
					header('Location:'.$url);
				}
			}
			
			// Load the correct file depending on the URL (copied from template-loader.php)
			$template = __templateLoader();
			
			$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.$template;
			if(file_exists($file))
			{
				include($file);
				exit(0);
			}
		}
	}
}

/**
 * Work out which theme file to use
 * @return string
 */
function __templateLoader()
{
	if ( is_404()) {
		return '404.php';
	} else if ( is_search()) {
		return 'search.php';
	} else if ( is_home()) {
		return 'index.php';
	} else if ( is_single()) {
		return 'single.php';
	} else if ( is_page()) {
		return 'page.php';
	} else if ( is_archive()) {
		return 'archive.php';
	} else if (file_exists(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'index.php' )) {
		return 'index.php';
	}
}

/**
 * Perform a device detection check
 * @return boolean
 */
function __testForMobile()
{
	global $waplSoapClient;
	global $waplHeaders;
	
	if(isset($_REQUEST['mobile']) && $_REQUEST['mobile'] == 0)
	{
		setcookie('isMobile', "", time()-3600, '/');
		setcookie('isMobile', "0", time()+3600, '/');
		return false;
	} else if(isset($_REQUEST['mobile']) && $_REQUEST['mobile'] == 1)
	{
		setcookie('isMobile', "", time()-3600, '/');
		setcookie('isMobile', "1", time()+3600, '/');
		return true;
	}
	
	if(!get_option('architect_devkey'))
	{
		return false;
	}
	
	// Check for existence of a cookie
	if(isset($_COOKIE['isMobile']) AND $_COOKIE['isMobile'] == true)
	{
		return true;
	} else if(isset($_COOKIE['isMobile']) AND $_COOKIE['isMobile'] == false)
	{
		return false;
	} else
	{
		if(ARCHITECT_DEBUG)
		{
			return true;
		}
		if(ARCHITECT_DO_SOAP)
		{
			// Test for mobile
			$params = array(
				'devKey' => get_option('architect_devkey'),
				'deviceHeaders' => $waplHeaders
			);
		
			$result = @$waplSoapClient->isMobileDevice($params);
			if(is_soap_fault($result))
			{
				// There is a SOAP error! probably a dev key error
				return false;
			}  else
			{
				if($result)
				{
					// Set a cookie to remember the outcome!
					setcookie('isMobile', true, time()+3600, '/');
					return true;
				} else
				{
					setcookie('isMobile', false, time()+3600, '/');
					return false;
				}
			}
		} else if(ARCHITECT_DO_REST)
		{
			$postfields = array(
				'devKey' => get_option('architect_devkey'),
				'headers' => $waplHeaders
			);
			
			$c = curl_init();
			curl_setopt($c, CURLOPT_URL, 'http://webservices.wapple.net/isMobileDevice.php');
			curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($c, CURLOPT_POST, 1);
			curl_setopt($c, CURLOPT_POSTFIELDS, $postfields);
			
			$result = curl_exec($c);
			
			curl_close($c);
			if($result == 1)
			{
				setcookie('isMobile', true, time()+3600, '/');
				return true;
			} else
			{
				setcookie('isMobile', $result, time()+3600, '/');
				return false;
			}
		}
	}
}

/**
 * Get a SOAP client
 * @return mixed
 */
function __getSoapClient()
{
	if(ARCHITECT_DEBUG)
	{
		return false;
	}
	if(ARCHITECT_DO_SOAP)
	{
		return new SoapClient('http://webservices.wapple.net/wapl.wsdl', array('exceptions' => 0));
	} else
	{
		return false;
	}	
}

/**
 * Build device header array that SOAP can use
 * @return array
 */
function __getHeaders()
{
	if(ARCHITECT_DO_SOAP)
	{
		$headers = array();
		foreach($_SERVER as $key => $val)
		{
			$headers[] = array('name' => $key, 'value' => $val);
		}
		return $headers;
	} else
	{
		$headers = '';
		foreach($_SERVER as $key => $val)
		{
			$headers .= $key.':'.$val.'|';
		}
		return $headers;
	}
}

// Add the deviceDetection function to the template_redirect filter
add_action('template_redirect', 'deviceDetection');
// Add architect options to admin menu
add_action('admin_menu', 'add_architect_options_page');
// Add notice to WordPress if we have an architect error
if(function_exists('ArchitectInitError'))
{
	add_action('admin_head','ArchitectInitError');
}

/**
 * Add architect admin options
 * @return void
 */
function add_architect_options_page()
{
	if(get_bloginfo('version') < '2.3')
	{
		add_options_page('Wapple Architect Settings', 'Wapple Architect', 8, basename(__FILE__), 'architect_options_page');
	} else
	{
		add_menu_page('Wapple Architect', 'Architect', -1, __FILE__, __FUNCTION__, WP_PLUGIN_URL.'/'.get_wapl_plugin_base().'/admin/architect.png');
		add_submenu_page(__FILE__, 'Wapple Architect Status', 'Status', 8, 'architect-status', 'architect_options_status');
		add_submenu_page(__FILE__, 'Wapple Architect Basic Settings', 'Basic', 8, 'architect-basic', 'architect_options_basic');
		add_submenu_page(__FILE__, 'Wapple Architect Advanced Settings', 'Advanced', 8, 'architect-advanced', 'architect_options_advanced');
		add_submenu_page(__FILE__, 'Wapple Architect Home Page Settings', 'Home Page', 8, 'architect-home', 'architect_options_home');
		add_submenu_page(__FILE__, 'Wapple Architect Home Page by Category Settings', 'Home Page by Category', 8, 'architect-homebycat', 'architect_options_homebycat');
		add_submenu_page(__FILE__, 'Wapple Architect Posts Settings', 'Posts Page', 8, 'architect-posts', 'architect_options_posts');
		add_submenu_page(__FILE__, 'Wapple Architect Archives Page Settings', 'Archives Pages', 8, 'architect-archives', 'architect_options_archives');
		add_submenu_page(__FILE__, 'Wapple Architect Search Page Settings', 'Search', 8, 'architect-search', 'architect_options_search');
		add_submenu_page(__FILE__, 'Wapple Architect Theme Settings', 'Mobile Theme', 8, 'architect-theme', 'architect_options_theme');
	}
}

if(!function_exists('get_wapl_plugin_base'))
{
	function get_wapl_plugin_base()
	{
		return $base = substr(dirname(__FILE__), (strrpos(dirname(__FILE__), DIRECTORY_SEPARATOR)+1), strlen(dirname(__FILE__)));
	}
}

function architect_check_path($path)
{
	$path = str_replace(WP_UPLOAD_DIR, '', $path);
	
	$dirExplode = explode(DIRECTORY_SEPARATOR, $path);
	$pathToCheck = WP_UPLOAD_DIR;
	foreach($dirExplode as $key => $val)
	{
		if(!file_exists($pathToCheck))
		{
			@mkdir($pathToCheck, 0777);
		}
		$pathToCheck .= $val.DIRECTORY_SEPARATOR;
	}
}
// Register activation
register_activation_hook(__FILE__, 'architect_install');

// Architect install script 
function architect_install()
{
	if(!$blog_id = get_option('blog_id'))
	{
		$blog_id = 0;
	}
	
	global $wpdb;
	
	$sql = '
	INSERT INTO `'.$wpdb->prefix.'options` 
	(`blog_id`, `option_name`, `option_value`, `autoload`) 
	VALUES
	('.$blog_id.', \'architect_headerimagelinktohome\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_home_showdate\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_show_blogtitle\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_use_meta\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_doform\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_accesskeys\', \'0\', \'yes\'),
	('.$blog_id.', \'architect_home_removecaptions\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_home_imagescale\', \'50\', \'yes\'),
	('.$blog_id.', \'architect_home_imagequality\', \'95\', \'yes\'),
	('.$blog_id.', \'architect_home_olderposts\', \'older posts\', \'yes\'),
	('.$blog_id.', \'architect_single_imagescale\', \'50\', \'yes\'),
	('.$blog_id.', \'architect_single_imagequality\', \'95\', \'yes\'),
	('.$blog_id.', \'architect_page_imagescale\', \'50\', \'yes\'),
	('.$blog_id.', \'architect_page_imagequality\', \'95\', \'yes\'),
	('.$blog_id.', \'architect_single_paginglength\', \'2000\', \'yes\'),
	('.$blog_id.', \'architect_single_allowcomments\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_showcomments\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_dopaging\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_showfootertext\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_showhome\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_nextpage\', \'more\', \'yes\'),
	('.$blog_id.', \'architect_single_prevpage\', \'back\', \'yes\'),
	('.$blog_id.', \'architect_single_previouspost\', \'previous post\', \'yes\'),
	('.$blog_id.', \'architect_single_nextpost\', \'next post\', \'yes\'),
	('.$blog_id.', \'architect_single_homepost\', \'home\', \'yes\'),
	('.$blog_id.', \'architect_single_shownext\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_showtags\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_tagtext\', \'Tag\', \'yes\'),
	('.$blog_id.', \'architect_single_metadatatext\', \'This entry was posted on <date> at <time> and is filed under <category>\', \'yes\'),
	('.$blog_id.', \'architect_single_commentsaystext\', \'says\', \'yes\'),
	('.$blog_id.', \'architect_single_commentsingletext\', \'comment\', \'yes\'),
	('.$blog_id.', \'architect_single_commentpluraltext\', \'comments\', \'yes\'),
	('.$blog_id.', \'architect_single_leaveareplytext\', \'Leave a Reply\', \'yes\'),
	('.$blog_id.', \'architect_single_leaveareplynametext\', \'Name\', \'yes\'),
	('.$blog_id.', \'architect_single_leaveareplyemailtext\', \'Email\', \'yes\'),
	('.$blog_id.', \'architect_single_leaveareplywebsitetext\', \'Website\', \'yes\'),
	('.$blog_id.', \'architect_single_leaveareplycommenttext\', \'Comment\', \'yes\'),
	('.$blog_id.', \'architect_single_leaveareplysubmittext\', \'Submit\', \'yes\'),
	('.$blog_id.', \'architect_single_passwordtext\', \'Enter post password\', \'yes\'),
	('.$blog_id.', \'architect_single_passwordbuttontext\', \'Submit\', \'yes\'),
	('.$blog_id.', \'architect_archive_cattext\', \'Archive for the \"<category>\" Category\', \'yes\'),
	('.$blog_id.', \'architect_archive_tagtext\', \'Posts tagged \"<tag>\"\', \'yes\'),
	('.$blog_id.', \'architect_archive_datetext\', \'Archive for\', \'yes\'),
	('.$blog_id.', \'architect_archive_authortext\', \'Author Archive\', \'yes\'),
	('.$blog_id.', \'architect_archive_blogarchivetext\', \'Blog Archives\', \'yes\'),
	('.$blog_id.', \'architect_archive_hometext\', \'Home\', \'yes\'),
	('.$blog_id.', \'architect_archive_olderentriestext\', \'Older Entries\', \'yes\'),
	('.$blog_id.', \'architect_archive_newerentriestext\', \'Newer Entries\', \'yes\'),
	('.$blog_id.', \'architect_archive_nocattext\', "Sorry, there aren\'t any posts in the <category> category yet.", \'yes\'),
	('.$blog_id.', \'architect_archive_nodatetext\', "Sorry, but there aren\'t any posts with this date.", \'yes\'),
	('.$blog_id.', \'architect_archive_noauthortext\', "Sorry, but there aren\'t any posts by <author> yet.", \'yes\'),
	('.$blog_id.', \'architect_archive_nopoststext\', "No posts found", \'yes\'),
	('.$blog_id.', \'architect_advanced_404text\', "Error 404 - Not Found", \'yes\'),
	('.$blog_id.', \'architect_home_posts_per_page\', \''.get_option('posts_per_page').'\', \'yes\'),
	('.$blog_id.', \'architect_home_excerpt_override\', \'300\', \'yes\'),
	('.$blog_id.', \'architect_search_title\', \'Search Results\', \'yes\'),
	('.$blog_id.', \'architect_search_hometext\', \'Home\', \'yes\'),
	('.$blog_id.', \'architect_search_olderentriestext\', \'Older Entries\', \'yes\'),
	('.$blog_id.', \'architect_search_newerentriestext\', \'Newer Entries\', \'yes\'),
	('.$blog_id.', \'architect_search_writtenbytext\', \'Written by\', \'yes\'),
	('.$blog_id.', \'architect_search_tagstext\', \'Tags\', \'yes\'),
	('.$blog_id.', \'architect_search_postedintext\', \'Posted in\', \'yes\'),
	('.$blog_id.', \'architect_search_notext\', \'No posts found. Try a different search?\', \'yes\'),
	('.$blog_id.', \'architect_search_boxtitletext\', \'Search\', \'yes\'),
	('.$blog_id.', \'architect_search_boxsubmittext\', \'Submit\', \'yes\'),
	('.$blog_id.', \'architect_showfootertext\', \'Powered by [url=http://http://mobilewebjunkie.com/wordpress-mobile-plugin-install-guide-and-faq/]Wapple Architect Mobile Plugin[/url]\', \'yes\')';
	$result = $wpdb->query($sql);
	
	// Check a few paths exist
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'header'.DIRECTORY_SEPARATOR;
	architect_check_path($file);
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'footer'.DIRECTORY_SEPARATOR;
	architect_check_path($file);
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'postHeader'.DIRECTORY_SEPARATOR;
	architect_check_path($file);
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR;
	architect_check_path($file);
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'style.css';
	architect_check_path($file);
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'custom_style.css';
	architect_check_path($file);
	
	// Copy stylesheet to default location
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'style.css';
	
	if(!file_exists($file))
	{
		@file_put_contents($file, "");
		if(is_writable($file))
		{
			file_put_contents($file, file_get_contents(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'style.css'));
		}
	}
	
	// Copy custom stylesheet to default location
	$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'custom_style.css';
	if(!file_exists($file))
	{
		@file_put_contents($file, "");
		if(is_writable($file))
		{
			file_put_contents($file, file_get_contents(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'custom_style.css'));
		}
	}
}

add_filter('plugin_row_meta', 'architect_filter_plugin_links', 10, 2);

function architect_filter_plugin_links($links, $file)
{
	if ( $file == plugin_basename(__FILE__) )
	{
		$links[] = '<a href="/wp-admin/admin.php?page=architect-basic">' . __('Settings') . '</a>';
	}
	
	return $links;
}

if(!function_exists('architect_curPageURL'))
{
	function architect_curPageURL() 
	{
		$pageURL = 'http';
		if (isset($_SERVER["HTTPS"]) AND $_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
		$pageURL .= "://";
		if ($_SERVER["SERVER_PORT"] != "80") {
			$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
		} else 
		{
			$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
		}
		return $pageURL;
	}
}

if(!function_exists('architect_buildUrl'))
{
	function architect_buildUrl($url, $options = array())
	{
		unset($_GET['mobile']);
		
		if(!isset($options['mobile']))
		{
			$options['mobile'] = 1;
		}
		$parsedUrl = parse_url($url);
		
		$return = $parsedUrl['scheme'].'://'.$parsedUrl['host'].$parsedUrl['path'];
		
		$i = 0;
		foreach($_GET as $key => $val)
		{
			if($i == 0)
			{
				$return .= '?';
			} else
			{
				$return .= '&';
			}
			
			$return .= $key.'='.$val;
			$i++;
		}
		foreach($options as $key => $val)
		{
			if($i == 0)
			{
				$return .= '?';
			} else
			{
				$return .= '&';
			}
			
			$return .= $key.'='.$val;
			$i++;
		}

		return htmlspecialchars($return);
	}
}

function architect_web_footer()
{
	echo '<div id="deviceSwitcher">View in: <a href="'.architect_buildUrl(architect_curPageURL(), array('mobile' => 1)).'">Mobile</a> | Standard</div>';
}
if(get_option('architect_showswitchtodesktop'))
{
	add_action('wp_footer', 'architect_web_footer');
}

function architect_register_head()
{
	$siteurl = get_option('siteurl');
	$url = $siteurl . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/admin/architect.css';
	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"".$url."\" />\n";
	$url = $siteurl . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/admin/architect.js';
	echo "<script type=\"text/javascript\" src=\"".$url."\"></script>\n";
	$url = $siteurl . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/admin/prototype.js';
	echo '<script type="text/javascript" src="'.$url.'"></script>';
	
}
add_action('admin_head', 'architect_register_head');

if(!function_exists('jquery_no_conflict_follows_jquery'))
{
	function jquery_no_conflict_follows_jquery( $js_array ) { if ( false === $jquery = array_search( 'jquery', $js_array ) ) return $js_array; if ( false === $jquery_no_conflict = array_search( 'jquery_no_conflict', $js_array ) ) return $js_array; if ( $jquery_no_conflict == $jquery + 1 ) return $js_array; array_splice( $js_array, $jquery + 1, 0, 'jquery_no_conflict' ); unset($js_array[$jquery_no_conflict + ($jquery_no_conflict < $jquery ? 0 : 1)]); return $js_array; }
} 
add_filter( 'print_scripts_array', 'jquery_no_conflict_follows_jquery' );

/**
 * Convert any other chars
 * 
 * @param string $string
 * @access public
 * @return string
 */
function architectCharsOther($string)
{
	$chars = array(
		'’' => '&#39;','—' => '&#45;', '«' => '&#171;', '»' => '&#187;', '&laquo;' => '&#171;', 
		'&raquo;' => '&#187;', '–' => '&#45;', '&hellip;' => '&#8230;'
	);
	return str_replace(array_keys($chars), array_values($chars), $string);
}

if(!function_exists('architect_replace_tag'))
{
	function architect_replace_tag($tag, $replacement, $string)
	{
		$string = str_replace($tag, $replacement, $string);
		return strip_tags($string);
		
	}	
}
?>